@@ -9,9 +9,10 @@ import xarray as xr
 import numpy as np
 import h5py
 
-from .types import Numpy, Direction, Array, numpy_encoding, Literal, Ax
+from .types import Numpy, Direction, Array, numpy_encoding, Literal, Ax, Coordinate, Symmetry
 from .base import Tidy3dBaseModel
 from .simulation import Simulation
+from .grid import YeeGrid
 from .mode import ModeSpec
 from .viz import add_ax_if_none, equal_aspect
 from ..log import log, DataError
@@ -397,6 +398,53 @@ class AbstractFieldData(CollectionData, ABC):
         # import pdb; pdb.set_trace()
         return xr.Dataset(centered_data_dict)
 
+    # pylint:disable=too-many-locals
+    def apply_syms(self, new_grid: YeeGrid, sym_center: Coordinate, symmetry: Symmetry):
+        """Create a new AbstractFieldData subclass by interpolating on the supplied ``new_grid``,
+        using symmetries as defined by ``sym_center`` and ``symmetry``."""
+
+        new_data_dict = {}
+        yee_grid_dict = new_grid.yee.grid_dict
+        # Defines how field components are affected by a positive symmetry along each of the axes
+        component_sym_dict = {
+            "Ex": [-1, 1, 1],
+            "Ey": [1, -1, 1],
+            "Ez": [1, 1, -1],
+            "Hx": [1, -1, -1],
+            "Hy": [-1, 1, -1],
+            "Hz": [-1, -1, 1],
+        }
+
+        for field, scalar_data in self.data_dict.items():
+            new_data = scalar_data.data
+
+            # Get new grid locations
+            yee_coords = yee_grid_dict[field].to_list
+
+            # Apply symmetries
+            zipped = zip("xyz", yee_coords, sym_center, symmetry)
+            for dim, (dim_name, coords, center, sym) in enumerate(zipped):
+                # There shouldn't be anything to do if there's no symmetry on this axis
+                if sym == 0:
+                    continue
+
+                # Get indexes of coords that lie on the left of the symmetry center
+                flip_inds = np.where(coords < center)[0]
+
+                # Get the symmetric coordinates on the right
+                coords[flip_inds] = 2 * center - coords[flip_inds]
+
+                # Interpolate. There generally shouldn't be values out of bounds except potentially
+                # when handling modes, in which case we set such values to zero.
+                new_data = new_data.interp({dim_name: coords}, kwargs={"fill_value": 0.0})
+
+                # Apply the correct +/-1 for the field component
+                new_data[{dim_name: flip_inds}] *= sym * component_sym_dict[field][dim]
+
+            new_data_dict[field] = type(scalar_data)(values=new_data.values, **new_data.coords)
+
+        return type(self)(data_dict=new_data_dict)
+
 
 class FreqData(MonitorData, ABC):
     """Stores frequency-domain data using an ``f`` dimension for frequency in Hz."""
