@@ -6,7 +6,7 @@ import pydantic as pd
 
 from ..constants import MICROMETER
 from .base import Tidy3dBaseModel
-from .types import Symmetry, Axis2D
+from .types import Axis2D
 from ..log import SetupError
 
 
@@ -17,7 +17,7 @@ class ModeSpec(Tidy3dBaseModel):
 
     Example
     -------
-    >>> mode_spec = ModeSpec(num_modes=3, target_neff=1.5, symmetries=(1, -1))
+    >>> mode_spec = ModeSpec(num_modes=3, target_neff=1.5)
     """
 
     num_modes: pd.PositiveInt = pd.Field(
@@ -28,13 +28,6 @@ class ModeSpec(Tidy3dBaseModel):
         None, title="Target effective index", description="Guess for effective index of the mode."
     )
 
-    symmetries: Tuple[Symmetry, Symmetry] = pd.Field(
-        (0, 0),
-        title="Tangential symmetries",
-        description="Symmetries to apply to the modes in the two tangential axes. "
-        "Values of (0, 1,-1) correspond to (none, even, odd) symmetries, respectvely.",
-    )
-
     num_pml: Tuple[pd.NonNegativeInt, pd.NonNegativeInt] = pd.Field(
         (0, 0),
         title="Number of PML layers",
