@@ -11,8 +11,9 @@ from mpl_toolkits.axes_grid1 import make_axes_locatable
 from descartes import PolygonPatch
 
 from .validators import assert_unique_names, assert_objects_in_sim_bounds
+from .validators import validate_mode_objects_symmetry
 from .geometry import Box
-from .types import Symmetry, Ax, Shapely, FreqBound, GridSize, inf
+from .types import Symmetry, Ax, Shapely, FreqBound, GridSize
 from .grid import Coords1D, Grid, Coords
 from .medium import Medium, MediumType, AbstractMedium
 from .structure import Structure
@@ -21,9 +22,10 @@ from .monitor import MonitorType
 from .pml import PMLTypes, PML, Absorber
 from .viz import StructMediumParams, StructEpsParams, PMLParams, SymParams
 from .viz import add_ax_if_none, equal_aspect
+from .viz import plotly_sim
 
 from ..version import __version__
-from ..constants import C_0, MICROMETER, SECOND, pec_val
+from ..constants import C_0, MICROMETER, SECOND, pec_val, inf
 from ..log import log, Tidy3dKeyError, SetupError
 
 # for docstring examples
@@ -113,6 +115,17 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         units=SECOND,
     )
 
+    symmetry: Tuple[Symmetry, Symmetry, Symmetry] = pydantic.Field(
+        (0, 0, 0),
+        title="Symmetries",
+        description="Tuple of integers defining reflection symmetry across a plane "
+        "bisecting the simulation domain normal to the x-, y-, and z-axis, respectvely. "
+        "Each element can be ``0`` (no symmetry), ``1`` (even, i.e. 'PMC' symmetry) or "
+        "``-1`` (odd, i.e. 'PEC' symmetry). "
+        "Note that the vectorial nature of the fields must be taken into account to correctly "
+        "determine the symmetry value.",
+    )
+
     structures: List[Structure] = pydantic.Field(
         [],
         title="Structures",
@@ -142,17 +155,6 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         "and periodic boundary conditions will be used.",
     )
 
-    symmetry: Tuple[Symmetry, Symmetry, Symmetry] = pydantic.Field(
-        (0, 0, 0),
-        title="Symmetries",
-        description="Tuple of integers defining reflection symmetry across a plane "
-        "bisecting the simulation domain normal to the x-, y-, and z-axis, respectvely. "
-        "Each element can be ``0`` (no symmetry), ``1`` (even, i.e. 'PMC' symmetry) or "
-        "``-1`` (odd, i.e. 'PEC' symmetry). "
-        "Note that the vectorial nature of the fields must be taken into account to correctly "
-        "determine the symmetry value.",
-    )
-
     shutoff: pydantic.NonNegativeFloat = pydantic.Field(
         1e-5,
         title="Shutoff Condition",
@@ -187,17 +189,6 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
 
     """ Validating setup """
 
-    @pydantic.validator("symmetry", always=True)
-    def not_supported_yet(cls, val):
-        """Log an error if non 0 value supplied."""
-        if any(sym_val != 0 for sym_val in val):
-            raise SetupError(
-                "Symmetry not supported in this version of tidy3d, "
-                "but will be included in coming release."
-                "For now, if symmetry is required, use the originl tidy3d."
-            )
-        return val
-
     @pydantic.validator("pml_layers", always=True)
     def set_none_to_zero_layers(cls, val):
         """if any PML layer is None, set it to an empty :class:`PML`."""
@@ -206,6 +197,8 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
     _structures_in_bounds = assert_objects_in_sim_bounds("structures")
     _sources_in_bounds = assert_objects_in_sim_bounds("sources")
     _monitors_in_bounds = assert_objects_in_sim_bounds("monitors")
+    _mode_sources_symmetries = validate_mode_objects_symmetry("sources")
+    _mode_monitors_symmetries = validate_mode_objects_symmetry("monitors")
 
     # assign names to unnamed structures, sources, and mediums
     # _structure_names = set_names("structures")
@@ -848,13 +841,8 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         List[Tuple[float, float]]
             List containing the number of absorber layers in - and + boundaries.
         """
-        num_layers = []
-        for pml_axis, pml_layer in enumerate(self.pml_layers):
-            if self.symmetry[pml_axis] != 0:
-                num_layers.append((0, pml_layer.num_layers))
-            else:
-                num_layers.append((pml_layer.num_layers, pml_layer.num_layers))
-        return num_layers
+
+        return [(pml.num_layers, pml.num_layers) for pml in self.pml_layers]
 
     @property
     def pml_thicknesses(self) -> List[Tuple[float, float]]:
@@ -1020,7 +1008,7 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             # loop through background_shapes (note: all background are non-intersecting or merged)
             for index, (_medium, _shape) in enumerate(background_shapes):
 
-                # if not intersetion, move onto next background shape
+                # if not intersection, move onto next background shape
                 if not shape & _shape:
                     continue
 
@@ -1042,6 +1030,27 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         # filter out any remaining None or empty shapes (shapes with area completely removed)
         return [(medium, shape) for (medium, shape) in background_shapes if shape]
 
+    def plotly(
+        self, x: float = None, y: float = None, z: float = None
+    ) -> "plotly.graph_objects.Figure":
+        """Plot the geometry cross section at single (x,y,z) coordinate using plotly.
+
+        Parameters
+        ----------
+        x : float = None
+            Position of plane in x direction, only one of x,y,z can be specified to define plane.
+        y : float = None
+            Position of plane in y direction, only one of x,y,z can be specified to define plane.
+        z : float = None
+            Position of plane in z direction, only one of x,y,z can be specified to define plane.
+
+        Returns
+        -------
+        plotly.graph_objects.Figure
+            A plotly figure.
+        """
+        return plotly_sim(self, x=x, y=y, z=z)
+
     @property
     def frequency_range(self) -> FreqBound:
         """Range of frequencies spanning all sources' frequency dependence.
@@ -1090,7 +1099,8 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
 
         return len(self.tmesh)
 
-    def _make_bound_coords_uniform(self, dl, center, size, num_layers):
+    @staticmethod
+    def _make_bound_coords_uniform(dl, center, size):
         """creates coordinate boundaries with uniform mesh (dl is float)"""
 
         num_cells = int(np.floor(size / dl))
@@ -1098,22 +1108,21 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         # Make sure there's at least one cell
         num_cells = max(num_cells, 1)
 
-        # snap to grid, recenter, and add PML
+        # snap to grid, recenter
         size_snapped = dl * num_cells
         bound_coords = center + np.linspace(-size_snapped / 2, size_snapped / 2, num_cells + 1)
-        bound_coords = self._add_pml_to_bounds(num_layers, bound_coords)
         return bound_coords
 
     @staticmethod
-    def _make_bound_coords_nonuniform(dl, center, size, num_layers):
+    def _make_bound_coords_nonuniform(dl, center, size):
         """creates coordinate boundaries with non-uniform mesh (dl is arraylike)"""
 
         # get bounding coordinates
         dl = np.array(dl)
         bound_coords = np.array([np.sum(dl[:i]) for i in range(len(dl) + 1)])
 
-        # shift coords to center at center of simulation along dimension
-        bound_coords = bound_coords - np.sum(dl) / 2 + center
+        # place the middle boundary at the center of the simulation along dimension
+        bound_coords += center - bound_coords[bound_coords.size // 2]
 
         # chop off any coords outside of simulation bounds
         bound_min = center - size / 2
@@ -1129,11 +1138,29 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         while bound_coords[-1] + dl_max <= bound_max:
             bound_coords = np.append(bound_coords, bound_coords[-1] + dl_max)
 
-        # add PML layers in using dl on edges
-        for _ in range(num_layers[0]):
-            bound_coords = np.insert(bound_coords, 0, bound_coords[0] - dl_min)
-        for _ in range(num_layers[1]):
-            bound_coords = np.append(bound_coords, bound_coords[-1] + dl_max)
+        return bound_coords
+
+    def _make_bound_coords(self, dim):
+        """Creates coordinate boundaries along dimension ``dim`` and handle PML and symmetries"""
+
+        dl = self.grid_size[dim]
+        center = self.center[dim]
+
+        # Make uniform or nonuniform boundaries depending on dl input
+        if isinstance(dl, float):
+            bound_coords = self._make_bound_coords_uniform(dl, center, self.size[dim])
+        else:
+            bound_coords = self._make_bound_coords_nonuniform(dl, center, self.size[dim])
+
+        # Add PML layers in using dl on edges
+        bound_coords = self._add_pml_to_bounds(self.num_pml_layers[dim], bound_coords)
+
+        # Enforce a symmetric grid by taking only the coordinates to the right of the center.
+        # Note that there's always a boundary at the simulation center.
+        if self.symmetry[dim] != 0:
+            bound_coords = bound_coords[bound_coords >= center]
+            bound_coords = np.append(2 * center - bound_coords[:0:-1], bound_coords)
+
         return bound_coords
 
     @property
@@ -1146,13 +1173,8 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             :class:`Grid` storing the spatial locations relevant to the simulation.
         """
         cell_boundary_dict = {}
-        zipped_vals = zip("xyz", self.grid_size, self.center, self.size, self.num_pml_layers)
-        for key, dl, center, size, num_layers in zipped_vals:
-            if isinstance(dl, float):
-                bound_coords = self._make_bound_coords_uniform(dl, center, size, num_layers)
-            else:
-                bound_coords = self._make_bound_coords_nonuniform(dl, center, size, num_layers)
-            cell_boundary_dict[key] = bound_coords
+        for dim, key in enumerate("xyz"):
+            cell_boundary_dict[key] = self._make_bound_coords(dim)
         boundaries = Coords(**cell_boundary_dict)
         return Grid(boundaries=boundaries)
 
@@ -1211,6 +1233,40 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         n_max, _ = AbstractMedium.eps_complex_to_nk(eps_max)
         return wvl_min / n_max
 
+    def min_sym_box(self, box: Box) -> Box:
+        """Compute the smallest Box restricted to the first quadrant in the presence of symmetries
+        that fully covers the original Box when symmetries are applied.
+
+        Parameters
+        ----------
+        box : :class:`Box`
+            Rectangular geometry.
+
+        Returns
+        -------
+        new_box : :class:`Box`
+            The smallest Box such that any point in ``box`` is either in ``new_box`` or can be
+            mapped from ``new_box`` using the simulation symmetries.
+        """
+
+        bounds_min, bounds_max = box.bounds
+        bmin_new, bmax_new = [], []
+
+        for (center, sym, bmin, bmax) in zip(self.center, self.symmetry, bounds_min, bounds_max):
+            if sym == 0 or center < bmin:
+                bmin_new.append(bmin)
+                bmax_new.append(bmax)
+            else:
+                if bmax < center:
+                    bmin_new.append(2 * center - bmax)
+                    bmax_new.append(2 * center - bmin)
+                else:
+                    # bmin <= center <= bmax
+                    bmin_new.append(center)
+                    bmax_new.append(max(bmax, 2 * center - bmin))
+
+        return Box.from_bounds(bmin_new, bmax_new)
+
     def discretize_inds(self, box: Box) -> List[Tuple[int, int]]:
         """Start and stopping indexes for the cells that intersect with a :class:`Box`.
 
@@ -1300,14 +1356,9 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
 
         Returns
         -------
-        Dict[str, xarray.DataArray]
-            Mapping of coordinate type to xarray DataArray containing permittivity data.
-            keys of dict are ``{'centers', 'boundaries', 'Ex', 'Ey', 'Ez', 'Hx', 'Hy', 'Hz'}``.
-            ``'centers'`` contains the permittivity at the yee cell centers.
-            `'boundaries'`` contains the permittivity at the corner intersections between yee cells.
-            ``'Ex'`` and other field keys contain the permittivity
-            at the corresponding field position in the yee lattice.
-            For details on xarray datasets,
+        xarray.DataArray
+            Datastructure containing the relative permittivity values and location coordinates.
+            For details on xarray DataArray objects,
             refer to `xarray's Documentaton <https://tinyurl.com/2zrzsp7b>`_.
         """
 
