@@ -1,19 +1,20 @@
 """Defines electric current sources for injecting light into simulation."""
 
 from abc import ABC, abstractmethod
-from typing import Union
+from typing import Union, Tuple
 
 import pydantic
 import numpy as np
 
 from .base import Tidy3dBaseModel
 from .types import Direction, Polarization, Ax, FreqBound, Array
-from .types import inf  # pylint:disable=unused-import
 from .validators import assert_plane, validate_name_str
 from .geometry import Box
 from .mode import ModeSpec
 from .viz import add_ax_if_none, SourceParams, equal_aspect
+from .viz import ARROW_COLOR_SOURCE, ARROW_ALPHA, ARROW_COLOR_POLARIZATION
 from ..constants import RADIAN, HERTZ, MICROMETER
+from ..constants import inf  # pylint:disable=unused-import
 from ..log import SetupError
 
 # in spectrum computation, discard amplitudes with relative magnitude smaller than cutoff
@@ -304,6 +305,34 @@ class FieldSource(Source, ABC):
 
     _plane_validator = assert_plane()
 
+    def plot(
+        self, x: float = None, y: float = None, z: float = None, ax: Ax = None, **kwargs
+    ) -> Ax:
+
+        # call the `Source.plot()` function first.
+        ax = super().plot(x=x, y=y, z=z, ax=ax, **kwargs)
+
+        # then add the arrow based on the propagation direction
+        ax = self._plot_arrow(
+            x=x,
+            y=y,
+            z=z,
+            ax=ax,
+            direction=self._dir_arrow,
+            color=ARROW_COLOR_SOURCE,
+            alpha=ARROW_ALPHA,
+            both_dirs=False,
+        )
+        return ax
+
+    @property
+    def _dir_arrow(self) -> Tuple[float, float, float]:
+        """Source direction normal vector in cartesian coordinates."""
+        normal = [0.0, 0.0, 0.0]
+        normal_axis = self.size.index(0.0)
+        normal[normal_axis] = 1.0 if self.direction == "+" else -1.0
+        return tuple(normal)
+
 
 class ModeSource(FieldSource):
     """Injects current source to excite modal profile on finite extent plane.
@@ -335,20 +364,6 @@ class ModeSource(FieldSource):
         "``num_modes`` in the solver will be set to ``mode_index + 1``.",
     )
 
-    # @pydantic.validator("mode_index", always=True)
-    # def mode_index_in_bounds(cls, val, values):
-    #     """Ensures number of modes in mode spec can support mode index."""
-    #     mode_spec = values.get("mode_spec")
-    #     if mode_spec is None:
-    #         raise SetupError("ModeSpec not found.")
-    #     num_modes = mode_spec.num_modes
-    #     if num_modes <= val:
-    #         raise SetupError(
-    #             f"ModeSpec contains {num_modes} modes, but mode index is {val}. "
-    #             "Either increase number of modes in the specifications or decrease mode index."
-    #         )
-    #     return val
-
 
 class AngledFieldSource(FieldSource):
     """Field Source with a polarization angle."""
@@ -367,6 +382,64 @@ class AngledFieldSource(FieldSource):
         units=RADIAN,
     )
 
+    def plot(
+        self, x: float = None, y: float = None, z: float = None, ax: Ax = None, **kwargs
+    ) -> Ax:
+
+        # call the `FieldSource.plot()` function first (including dir arrow)
+        ax = super().plot(x=x, y=y, z=z, ax=ax, **kwargs)
+
+        # then add another arrow based on the polarization direction
+        ax = self._plot_arrow(
+            x=x,
+            y=y,
+            z=z,
+            ax=ax,
+            direction=self._pol_arrow,
+            color=ARROW_COLOR_POLARIZATION,
+            alpha=ARROW_ALPHA,
+            both_dirs=False,
+        )
+        return ax
+
+    @staticmethod
+    def rotate(
+        vector: Tuple[float, float, float], axis: Tuple[float, float, float], angle: float
+    ) -> Array:
+        """Rotate a ``vector`` about a given ``axis`` vector by a given ``angle``."""
+
+        # Normalized axis vector components
+        (ux, uy, uz) = axis / np.linalg.norm(axis)
+
+        # General rotation matrix
+        rot_mat = np.zeros((3, 3))
+        cos = np.cos(angle)
+        sin = np.sin(angle)
+        rot_mat[0, 0] = cos + ux**2 * (1 - cos)
+        rot_mat[0, 1] = ux * uy * (1 - cos) - uz * sin
+        rot_mat[0, 2] = ux * uz * (1 - cos) + uy * sin
+        rot_mat[1, 0] = uy * ux * (1 - cos) + uz * sin
+        rot_mat[1, 1] = cos + uy**2 * (1 - cos)
+        rot_mat[1, 2] = uy * uz * (1 - cos) - ux * sin
+        rot_mat[2, 0] = uz * ux * (1 - cos) - uy * sin
+        rot_mat[2, 1] = uz * uy * (1 - cos) + ux * sin
+        rot_mat[2, 2] = cos + uz**2 * (1 - cos)
+
+        return rot_mat @ vector
+
+    @property
+    def _pol_arrow(self) -> Tuple[float, float, float]:
+        """Source polarization normal vector in cartesian coordinates."""
+        normal_plane = [0.0, 0.0, 0.0]
+        normal_axis = self.size.index(0.0)
+        normal_plane[normal_axis] = 1.0
+        normal_prop = list(self._dir_arrow)
+        pol_vector = np.cross(normal_plane, normal_prop)
+        if np.all(pol_vector == 0.0):
+            pol_vector = np.array((0, 1, 0)) if normal_axis == "x" else np.array((1, 0, 0))
+
+        return self.rotate(pol_vector, normal_prop, angle=self.pol_angle)
+
 
 class PlaneWave(AngledFieldSource):
     """Uniform current distribution on an infinite extent plane.
@@ -423,6 +496,16 @@ class GaussianBeam(AngledFieldSource):
         units=RADIAN,
     )
 
+    @property
+    def _dir_arrow(self) -> Tuple[float, float, float]:
+        """Source direction normal vector in cartesian coordinates."""
+        radius = 1.0 if self.direction == "+" else -1.0
+        dx = radius * np.cos(self.angle_phi) * np.sin(self.angle_theta)
+        dy = radius * np.sin(self.angle_phi) * np.sin(self.angle_theta)
+        dz = radius * np.cos(self.angle_theta)
+        normal_axis = self.size.index(0.0)
+        return self.unpop_axis(dz, (dx, dy), axis=normal_axis)
+
 
 # sources allowed in Simulation.sources
 SourceType = Union[VolumeSource, PlaneWave, ModeSource, GaussianBeam]
