@@ -15,6 +15,7 @@ from ...components import ModeMonitor
 from ...components import ModeSource, GaussianPulse
 from ...components.types import Direction
 from ...components.data import ScalarFieldData, FieldData
+from ...log import SetupError
 
 from .solver import compute_modes
 
@@ -109,8 +110,23 @@ class ModeSolver:
 
         normal_axis = self.plane.size.index(0.0)
 
+        # get the in-plane grid coordinates on which eps and the mode fields live
+        plane_grid = self.simulation.discretize(self.plane)
+
+        # restrict to a smaller plane if symmetries present in the simulation
+        plane_sym = self.simulation.min_sym_box(self.plane)
+        plane_grid_sym = self.simulation.discretize(plane_sym)
+
+        # Coords and symmetry arguments to the solver (restricted to in-plane)
+        _, solver_coords = self.plane.pop_axis(plane_grid_sym.boundaries.to_list, axis=normal_axis)
+        mode_symmetry = list(self.simulation.symmetry)
+        for dim in range(3):
+            if self.simulation.center[dim] != self.plane.center[dim]:
+                mode_symmetry[dim] = 0
+        _, solver_symmetry = self.plane.pop_axis(mode_symmetry, axis=normal_axis)
+
         # Get diagonal epsilon components in the plane
-        (eps_xx, eps_yy, eps_zz) = self.get_epsilon()
+        (eps_xx, eps_yy, eps_zz) = self.get_epsilon(plane_sym)
 
         # get rid of normal axis
         eps_xx = np.squeeze(eps_xx, axis=normal_axis)
@@ -122,35 +138,23 @@ class ModeSolver:
             (eps_xx, eps_yy, eps_zz), axis=normal_axis
         )
 
-        # get the in-plane grid coordinates on which eps and the mode fields live
-        plane_grid = self.simulation.discretize(self.plane)
-        _, plane_coords = self.plane.pop_axis(plane_grid.boundaries.to_list, axis=normal_axis)
-
-        # note: from this point on, in waveguide coordinates (propagating in z)
-
         # construct eps_cross section to feed to mode solver
         eps_cross = np.stack((eps_wg_xx, eps_wg_yy, eps_wg_zz))
 
-        # Nx, Ny = eps_cross.shape[1:]
-        # if mode_spec.symmetries[0] != 0:
-        #     eps_cross = np.stack(tuple(e[Nx // 2, :] for e in eps_cross))
-        # if mode_spec.symmetries[1] != 0:
-        #     eps_cross = np.stack(tuple(e[:, Ny // 2] for e in eps_cross))
-
+        # Compute the modes
         mode_fields, n_eff_complex = compute_modes(
             eps_cross=eps_cross,
-            coords=plane_coords,
+            coords=solver_coords,
             freq=self.freq,
             mode_spec=mode_spec,
+            symmetry=solver_symmetry,
         )
 
-        def rotate_field_coords(e_field, h_field):
+        def rotate_field_coords(field):
             """move the propagation axis=z to the proper order in the array"""
-            Ex, Ey, Ez = np.moveaxis(e_field, source=3, destination=1 + normal_axis)
-            e_rot = np.stack(self.simulation.unpop_axis(Ez, (Ex, Ey), axis=normal_axis), axis=0)
-            Hx, Hy, Hz = np.moveaxis(h_field, source=3, destination=1 + normal_axis)
-            h_rot = np.stack(self.simulation.unpop_axis(Hz, (Hx, Hy), axis=normal_axis), axis=0)
-            return (e_rot, h_rot)
+            f_x, f_y, f_z = np.moveaxis(field, source=3, destination=1 + normal_axis)
+            f_rot = np.stack(self.plane.unpop_axis(f_z, (f_x, f_y), axis=normal_axis), axis=0)
+            return f_rot
 
         modes = []
         for mode_index in range(mode_spec.num_modes):
@@ -164,20 +168,9 @@ class ModeSolver:
             E *= np.exp(-1j * phi)
             H *= np.exp(-1j * phi)
 
-            # # Handle symmetries
-            # if mode.symmetries[0] != 0:
-            #     E_half = E[:, 1:, ...]
-            #     H_half = H[:, 1:, ...]
-            #     E = np.concatenate((+E_half[:, ::-1, ...], E_half), axis=1)
-            #     H = np.concatenate((-H_half[:, ::-1, ...], H_half), axis=1)
-            # if mode.symmetries[1] != 0:
-            #     E_half = E[:, :, 1:, ...]
-            #     H_half = H[:, :, 1:, ...]
-            #     E = np.concatenate((+E_half[:, :, ::-1, ...], E_half), axis=2)
-            #     H = np.concatenate((-H_half[:, :, ::-1, ...], H_half), axis=2)
-
             # Rotate back to original coordinates
-            (Ex, Ey, Ez), (Hx, Hy, Hz) = rotate_field_coords(E, H)
+            (Ex, Ey, Ez) = rotate_field_coords(E)
+            (Hx, Hy, Hz) = rotate_field_coords(H)
 
             # apply -1 to H fields if a reflection was involved in the rotation
             if normal_axis == 1:
@@ -191,9 +184,7 @@ class ModeSolver:
             # note: re-discretizing, need to make consistent.
             data_dict = {}
             for field_name, field in fields.items():
-                plane_grid = self.simulation.discretize(self.plane)
-                plane_coords = plane_grid[field_name]
-                xyz_coords = [plane_coords.x, plane_coords.y, plane_coords.z]
+                xyz_coords = plane_grid_sym[field_name].to_list
                 xyz_coords[normal_axis] = [self.plane.center[normal_axis]]
                 data_dict[field_name] = ScalarFieldData(
                     x=xyz_coords[0],
@@ -203,8 +194,11 @@ class ModeSolver:
                     values=field[..., None],
                 )
 
+            field_data = FieldData(data_dict=data_dict).apply_syms(
+                plane_grid, self.simulation.center, self.simulation.symmetry
+            )
             mode_info = ModeInfo(
-                field_data=FieldData(data_dict=data_dict),
+                field_data=field_data,
                 mode_spec=mode_spec,
                 mode_index=mode_index,
                 n_eff=n_eff_complex[mode_index].real,
@@ -215,12 +209,12 @@ class ModeSolver:
 
         return modes
 
-    def get_epsilon(self):
+    def get_epsilon(self, plane):
         """Compute the diagonal components of the epsilon tensor in the plane."""
 
-        eps_xx = self.simulation.epsilon(self.plane, "Ex", self.freq)
-        eps_yy = self.simulation.epsilon(self.plane, "Ey", self.freq)
-        eps_zz = self.simulation.epsilon(self.plane, "Ez", self.freq)
+        eps_xx = self.simulation.epsilon(plane, "Ex", self.freq)
+        eps_yy = self.simulation.epsilon(plane, "Ey", self.freq)
+        eps_zz = self.simulation.epsilon(plane, "Ez", self.freq)
 
         return np.stack((eps_xx, eps_yy, eps_zz), axis=0)
 
